﻿using Android.App;
using Android.Widget;
using Android.OS;
using Com.Syncfusion.Charts;
using System.Collections.ObjectModel;
using Android.Graphics;
using Android.Views;
using System;

namespace ZoomPanSample
{
    [Activity(Label = "ZoomPanSample", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        ChartZoomPanBehavior zoomPan;
        DateTimeAxis xAxis;
        NumericalAxis yAxis;
        private static DateTime enddate;
        private bool isLoadTime = true;

        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);

            LinearLayout rootLayout = new LinearLayout(this);
            rootLayout.Orientation = Orientation.Vertical;

            SfChart chart = new SfChart(this);
            chart.LayoutParameters = new ViewGroup.LayoutParams(ViewGroup.LayoutParams.MatchParent, ViewGroup.LayoutParams.MatchParent);
            chart.SetBackgroundColor(Color.White);

            xAxis = new DateTimeAxis();
            xAxis.ActualRangeChanged += XAxis_ActualRangeChanged;
            chart.PrimaryAxis = xAxis;

            yAxis = new NumericalAxis();
            chart.SecondaryAxis = yAxis;

            LineSeries series = new LineSeries();
            series.ItemsSource = GetData();
            series.XBindingPath = "XValue";
            series.YBindingPath = "YValue";
            chart.Series.Add(series);

            zoomPan = new ChartZoomPanBehavior();
            chart.Behaviors.Add(zoomPan);

            Button button = new Button(this);
            button.Text = "Zoom";
            button.Click += Button_Click;

            rootLayout.AddView(button);
            rootLayout.AddView(chart);
            // Set our view from the "main" layout resource
            SetContentView(rootLayout);
        }

        private void XAxis_ActualRangeChanged(object sender, ChartAxis.ActualRangeChangedEventArgs e)
        {
            if (isLoadTime)
            {
                zoomPan.ZoomByRange(xAxis, enddate.AddSeconds(-1000), enddate);
            }

            isLoadTime = false;
        }

        private void Button_Click(object sender, System.EventArgs e)
        {
            zoomPan.ZoomByRange(xAxis, enddate.AddSeconds(-1000), enddate); //zooms in properly!
        }

        public static ObservableCollection<DataModel> GetData()
        {
            var datas = new ObservableCollection<DataModel>();
            Random rnd = new Random();

            //Generating Random Data
            DateTime dt = DateTime.Now;
            for (int i = 0; i < 100; i++)
            {
                var xaxisPoint = dt.AddSeconds(i + 5);
                datas.Add(new DataModel(xaxisPoint, rnd.Next(0, 5)));

                if (i == 99)
                {
                    enddate = xaxisPoint;
                }
            }

            return datas;
        }
    }
}

